function[smooth_array, wind] = movavg51b(array,drainarea,pixel_size,wind)

% movavg51.m performs a moving average of the elevation array, within a
% window of user-specified width. It takes as input the raw data array, 
% and the pixel size.  The code returns an array of the same size.  Edges 
% of the array are averaged on a progressively smaller window. 
%
% Code written by Eric Kirby (date unknown, but sometime in late 1998)
%
% USAGE:
%     smooth_array = movavg51(array,pixel_size,wind)
%
% INPUT:
%     array - input vector of data
%     pixel_size - distance between data points
%     wind - moving window size
%
% OUTPUT:
%      smooth_array - output of smoothed data
%
% Assumes units are in meters according to text, though it doesn't really 
% matter as long as entered window size and pixel_size are internally 
% consistent
%
% movavg51b.m -- Modified by KXW 1/10/07, improved by NMG 10/20/07 to break into segments 
% wherever drainage area
% more than doubles (value set by "ratio" (small trib entering mainstem)
% once drainage area is greater than "threshold" to avoid smoothing
% across trib junctions -- debugged but not extensively tested.

ratio = 2.1;
threshold = 5e6;

loop=1;

%error catching loop to make sure that wind is at least pixel_size:
while loop,
    if wind >= pixel_size,
        loop=0;
    else
        disp(sprintf('Error:  smoothing window size (%sm) must be >= 3x DEM posting (ie %sm)',num2str(wind),num2str(pixel_size*3)))
        wind = input('Enter the smoothing window size (m): ');
    end
end

% set length of raw data array and initialize new array
max_x = length(array);
smooth_array(1:length(array)) = zeros;

% next divide into segments defined by tributary junctions where drainage
% area more than doubles (value set by ratio).  first find seg_ind that mark end of upper
% segments and determine number of segments to be smoothed separately

%ordering is from high drainage area to low drainage area
%for some reason first drainage area is usually wrong, so ignore it
shift_drain = drainarea(2:max_x-1);
trim_drain = drainarea(3:max_x );
seg_ind = find(trim_drain > threshold & shift_drain./trim_drain > ratio);

if seg_ind
    %found areas that fit criteria
    seg_ind = seg_ind +1;
    %increase by one, because got rid of first point in drainage area
    %array
    num_segs = length(seg_ind)+1;
else
    num_segs = 1;
end

seg_length(1:num_segs) = zeros;
seg_end(1:num_segs) = zeros;
seg_start(1:num_segs) = zeros;

% determine start and endpoints each segment
%
if num_segs>1
    j = 1;
    seg_length(j) = seg_ind(j);
    seg_end(j) = seg_ind(j);
    seg_start(j) = 1;
    for j = 2:num_segs-1
        seg_length(j) = seg_ind(j)-seg_ind(j-1);
        seg_end(j) = seg_ind(j);
        seg_start(j) = seg_ind(j-1)+1;
    end

    j = num_segs;
    seg_length(j) = max_x - seg_ind(j-1);
    seg_end(j) = max_x;
    seg_start(j) = seg_ind(j-1)+1;
    shortest = min(seg_length);
    seg_start;
    seg_end;
else
    seg_length(1) =max_x;
    seg_end(1)=max_x;
    seg_start(1)=1;
    shortest = max_x;
end

% crash test to be sure segment lengths are greater than
% smoothing window length, reset wind if necessary (perhaps should pass
% this back to main program)
%
% alternative here would be to just do not smooth if segment is shorter
% than smoothing window

if wind/pixel_size > shortest
    disp(sprintf('Error:  smoothing window size must be less than minumum segment length (%sm)',num2str(shortest)))
    wind = input('Enter the smoothing window size (m): ');
end

% convert to pixels and test for an odd number, ie make it odd
wind_pix = round(wind/pixel_size);
if rem(wind_pix,2) == 0
    wind_pix = wind_pix - 1;
else
end

if wind_pix==1; %if smoothing window size is 1, no smoothing is done. exit fcn
    disp('No smoothing done in movavg3.m; smoothing window too small')
    smooth_array=array;
    return
end

half_width = (wind_pix-1)/2;

% loop the following running mean code for each segment, starting from
% divide

for k = 1:num_segs

    % set running mean for center of smooth array, each segment

    for i = half_width+seg_start(k):seg_end(k)-half_width
        smooth_array(i) = mean(array(i-half_width:i+half_width));
    end

    % set running mean for array ends, each segment
    smooth_array(seg_start(k)) = array(seg_start(k));
    for i = 2:half_width
        num = i+(i-1);
        num_2 = (num-1)/2;
        smooth_array(seg_start(k)-1+i) = mean(array(seg_start(k)-1+i-num_2:seg_start(k)-1+i+num_2));
    end

    smooth_array(seg_end(k)) = array(seg_end(k));
    for i = seg_end(k)-half_width+1:seg_end(k)-1
        num = seg_end(k) - i;
        smooth_array(i) = mean(array(i-num:i+num));
    end

end

